"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.configureUpdatesAsync = configureUpdatesAsync;
exports.syncUpdatesConfigurationAsync = syncUpdatesConfigurationAsync;

function _config() {
  const data = require("@expo/config");

  _config = function () {
    return data;
  };

  return data;
}

function _xdl() {
  const data = require("@expo/xdl");

  _xdl = function () {
    return data;
  };

  return data;
}

function _fsExtra() {
  const data = _interopRequireDefault(require("fs-extra"));

  _fsExtra = function () {
    return data;
  };

  return data;
}

function _log() {
  const data = _interopRequireDefault(require("../../../../log"));

  _log = function () {
    return data;
  };

  return data;
}

function _common() {
  const data = require("./common");

  _common = function () {
    return data;
  };

  return data;
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function configureUpdatesAsync(projectDir, exp) {
  (0, _common().ensureValidVersions)(exp);
  const username = await _xdl().UserManager.getCurrentUsernameAsync();

  const buildGradlePath = _config().AndroidConfig.Paths.getAppBuildGradle(projectDir);

  const buildGradleContent = await _fsExtra().default.readFile(buildGradlePath, 'utf8');

  if (!_config().AndroidConfig.Updates.isBuildGradleConfigured(buildGradleContent, projectDir, exp)) {
    const gradleScriptApply = _config().AndroidConfig.Updates.formatApplyLineForBuildGradle(projectDir, exp);

    await _fsExtra().default.writeFile(buildGradlePath, `${buildGradleContent}\n// Integration with Expo updates\n${gradleScriptApply}\n`);
  }

  const androidManifestPath = await _config().AndroidConfig.Paths.getAndroidManifestAsync(projectDir);

  if (!androidManifestPath) {
    throw new Error(`Could not find AndroidManifest.xml in project directory: "${projectDir}"`);
  }

  const androidManifest = await _config().AndroidConfig.Manifest.readAndroidManifestAsync(androidManifestPath);

  if (!_config().AndroidConfig.Updates.isMainApplicationMetaDataSynced(exp, androidManifest, username)) {
    const result = await _config().AndroidConfig.Updates.setUpdatesConfig(exp, androidManifest, username);
    await _config().AndroidConfig.Manifest.writeAndroidManifestAsync(androidManifestPath, result);
  }
}

async function syncUpdatesConfigurationAsync(projectDir, exp) {
  (0, _common().ensureValidVersions)(exp);
  const username = await _xdl().UserManager.getCurrentUsernameAsync();

  try {
    await ensureUpdatesConfiguredAsync(projectDir, exp);
  } catch (error) {
    _log().default.error('expo-updates module is not configured. Please run "expo eas:build:init" first to configure the project');

    throw error;
  }

  const androidManifestPath = await _config().AndroidConfig.Paths.getAndroidManifestAsync(projectDir);

  if (!androidManifestPath) {
    throw new Error(`Could not find AndroidManifest.xml in project directory: "${projectDir}"`);
  }

  let androidManifest = await _config().AndroidConfig.Manifest.readAndroidManifestAsync(androidManifestPath);

  if (!_config().AndroidConfig.Updates.areVersionsSynced(exp, androidManifest)) {
    androidManifest = _config().AndroidConfig.Updates.setVersionsConfig(exp, androidManifest);
    await _config().AndroidConfig.Manifest.writeAndroidManifestAsync(androidManifestPath, androidManifest);
  }

  if (!_config().AndroidConfig.Updates.isMainApplicationMetaDataSynced(exp, androidManifest, username)) {
    _log().default.warn('Native project configuration is not synced with values present in your app.json, run expo eas:build:init to make sure all values are applied in antive project');
  }
}

async function ensureUpdatesConfiguredAsync(projectDir, exp) {
  const buildGradlePath = _config().AndroidConfig.Paths.getAppBuildGradle(projectDir);

  const buildGradleContent = await _fsExtra().default.readFile(buildGradlePath, 'utf8');

  if (!_config().AndroidConfig.Updates.isBuildGradleConfigured(buildGradleContent, projectDir, exp)) {
    const gradleScriptApply = _config().AndroidConfig.Updates.formatApplyLineForBuildGradle(projectDir, exp);

    throw new Error(`Missing ${gradleScriptApply} in ${buildGradlePath}`);
  }

  const androidManifestPath = await _config().AndroidConfig.Paths.getAndroidManifestAsync(projectDir);

  if (!androidManifestPath) {
    throw new Error(`Could not find AndroidManifest.xml in project directory: "${projectDir}"`);
  }

  const androidManifest = await _config().AndroidConfig.Manifest.readAndroidManifestAsync(androidManifestPath);

  if (!_config().AndroidConfig.Updates.isMainApplicationMetaDataSet(androidManifest)) {
    throw new Error('Missing values in AndroidManifest.xml');
  }
}
//# sourceMappingURL=android.js.map